@@ -78,14 +78,14 @@ public:
 
 public slots:
 
+	void stabilizeForm();
+
+protected slots:
+
 	void stdoutNotifySlot(int);
-	void appendStdoutBuffer(const QString&);
-	void flushStdoutBuffer();
 
 	void contextMenu(const QPoint&);
 
-	void stabilizeForm();
-
 	void programReset();
 	void systemReset();
 	void promptRestart();
@@ -126,6 +126,11 @@ protected:
 
 	void closeEvent(QCloseEvent *pCloseEvent);
 
+	void appendStdoutBuffer(const QString&);
+	void flushStdoutBuffer();
+
+	bool stdoutBlock(int fd, bool bBlock) const;
+
 	void playLoadFiles( qsynthEngine *pEngine, const QStringList& files, bool bSetup);
 
 	bool decodeDragFiles(const QMimeSource * pEvent, QStringList& files);
