@@ -1,7 +1,7 @@
 // qsynthOptionsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2016, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -86,9 +86,6 @@ qsynthOptionsForm::qsynthOptionsForm (
 	QObject::connect(m_ui.SystemTrayQueryCloseCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
-	QObject::connect(m_ui.StartMinimizedCheckBox,
-		SIGNAL(stateChanged(int)),
-		SLOT(optionsChanged()));
 #endif
 	QObject::connect(m_ui.BaseFontSizeComboBox,
 		SIGNAL(editTextChanged(const QString&)),
@@ -164,7 +161,6 @@ void qsynthOptionsForm::setup ( qsynthOptions *pOptions )
 #ifdef CONFIG_SYSTEM_TRAY
 	m_ui.SystemTrayCheckBox->setChecked(m_pOptions->bSystemTray);
 	m_ui.SystemTrayQueryCloseCheckBox->setChecked(m_pOptions->bSystemTrayQueryClose);
-	m_ui.StartMinimizedCheckBox->setChecked(m_pOptions->bStartMinimized);
 #endif
 	if (m_pOptions->iBaseFontSize > 0) {
 		m_ui.BaseFontSizeComboBox->setEditText(
@@ -187,8 +183,6 @@ void qsynthOptionsForm::setup ( qsynthOptions *pOptions )
 	m_ui.SystemTrayCheckBox->setEnabled(false);
 	m_ui.SystemTrayQueryCloseCheckBox->setChecked(false);
 	m_ui.SystemTrayQueryCloseCheckBox->setEnabled(false);
-	m_ui.StartMinimizedCheckBox->setChecked(false);
-	m_ui.StartMinimizedCheckBox->setEnabled(false);
 #endif
 
 	// Done.
@@ -214,7 +208,6 @@ void qsynthOptionsForm::accept (void)
 	#ifdef CONFIG_SYSTEM_TRAY
 		m_pOptions->bSystemTray     = m_ui.SystemTrayCheckBox->isChecked();
 		m_pOptions->bSystemTrayQueryClose = m_ui.SystemTrayQueryCloseCheckBox->isChecked();
-		m_pOptions->bStartMinimized = m_ui.StartMinimizedCheckBox->isChecked();
 	#endif
 		m_pOptions->iBaseFontSize   = m_ui.BaseFontSizeComboBox->currentText().toInt();
 		// Knobs
@@ -290,9 +283,8 @@ void qsynthOptionsForm::stabilizeForm()
 	}
 
 #ifdef CONFIG_SYSTEM_TRAY
-	bEnabled = m_ui.SystemTrayCheckBox->isChecked();
-	m_ui.SystemTrayQueryCloseCheckBox->setEnabled(bEnabled);
-	m_ui.StartMinimizedCheckBox->setEnabled(bEnabled);
+	m_ui.SystemTrayQueryCloseCheckBox->setEnabled(
+		m_ui.SystemTrayCheckBox->isChecked());
 #endif
 
 	m_ui.DialogButtonBox->button(QDialogButtonBox::Ok)->setEnabled(bValid);
