@@ -1,7 +1,7 @@
 // qsynthSystemTray.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2016, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
 #include <QWidget>
 
 #include <QSystemTrayIcon>
+#include <QMenu>
 
 
 //----------------------------------------------------------------------------
@@ -68,10 +69,14 @@ protected slots:
 	// Handle systeam tray activity.
 	void activated(QSystemTrayIcon::ActivationReason);
 
+	// Context menu slot.
+	void contextMenuRequested();
+
 private:
 
 	// Instance pixmap and background color.
 	QIcon   m_icon;
+	QMenu   m_menu;
 	QPixmap m_pixmap;
 	QPixmap m_pixmapOverlay;
 	QColor  m_background;
